;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ol-notmuch" "20251101.2058"
  "Links to notmuch messages."
  '((emacs   "29.1")
    (compat  "30.1")
    (notmuch "0.38")
    (org     "9.7"))
  :url "https://github.com/tarsius/ol-notmuch"
  :commit "7655f5ea25ea40b7d0453ae6531cae59e5ea592f"
  :revdesc "7655f5ea25ea"
  :keywords '("hypermedia" "mail")
  :authors '(("Matthieu Lemerre" . "racin@free.fr"))
  :maintainers '(("Jonas Bernoulli" . "emacs.ol-notmuch@jonas.bernoulli.dev")))
